@@ -75,7 +75,8 @@ std::string sdf::findFile(const std::string &_filename, bool _searchLocalPath,
     return path.string();
 
   // Next check the versioned install path.
-  path = boost::filesystem::path(SDF_VERSION_PATH) / _filename;
+  path = boost::filesystem::path(SDF_SHARE_PATH) / "sdformat" /
+    sdf::SDF::version / _filename;
   if (boost::filesystem::exists(path))
     return path.string();
 
